==> sumus-6.4.5-sources.jar: io/intino/sumus/box/displays/notifiers/SumusOlapNotifier.java <==
package io.intino.sumus.box.displays.notifiers;

import io.intino.konos.alexandria.exceptions.*;
import io.intino.sumus.box.*;
import io.intino.sumus.box.schemas.*;

public class SumusOlapNotifier extends io.intino.konos.alexandria.activity.displays.AlexandriaDisplayNotifier {

    public SumusOlapNotifier(io.intino.konos.alexandria.activity.displays.AlexandriaDisplay display, io.intino.konos.alexandria.activity.displays.MessageCarrier carrier) {
        super(display, carrier);
    }

	public void olapRange(Range value) {
		putToDisplay("olapRange", "value", value);
	}

	public void timeRange(Range value) {
		putToDisplay("timeRange", "value", value);
	}

	public void scaleList(java.util.List<Scale> value) {
		putToDisplay("scaleList", "value", value);
	}

	public void updateScale(Scale value) {
		putToDisplay("updateScale", "value", value);
	}

	public void enableDrill() {
		putToDisplay("enableDrill");
	}

	public void disableDrill() {
		putToDisplay("disableDrill");
	}

	public void enableFilter() {
		putToDisplay("enableFilter");
	}

	public void disableFilter() {
		putToDisplay("disableFilter");
	}

	public void filtering() {
		putToDisplay("filtering");
	}

	public void notFiltering() {
		putToDisplay("notFiltering");
	}

	public void drilling() {
		putToDisplay("drilling");
	}

	public void notDrilling() {
		putToDisplay("notDrilling");
	}

	public void refreshDrill(Drill value) {
		putToDisplay("refreshDrill", "value", value);
	}

	public void refreshFilterList(java.util.List<Filter> value) {
		putToDisplay("refreshFilterList", "value", value);
	}

	public void ticketList(java.util.List<Ticket> value) {
		putToDisplay("ticketList", "value", value);
	}

	public void selectTicketList(java.util.List<Ticket> value) {
		putToDisplay("selectTicketList", "value", value);
	}

	public void byCategorization(Reference value) {
		putToDisplay("byCategorization", "value", value);
	}

	public void chartList(java.util.List<Chart> value) {
		putToDisplay("chartList", "value", value);
	}

	public void selectChart(String value) {
		putToDisplay("selectChart", "value", value);
	}

	public void openAnalyzeDialog() {
		putToDisplay("openAnalyzeDialog");
	}

	public void closeAnalyzeDialog() {
		putToDisplay("closeAnalyzeDialog");
	}
}

==> sumus-7.2.1-sources.jar: io/intino/sumus/box/displays/notifiers/SumusOlapNotifier.java <==
package io.intino.sumus.box.displays.notifiers;

import io.intino.konos.alexandria.exceptions.*;
import io.intino.sumus.box.*;
import io.intino.sumus.box.schemas.*;

public class SumusOlapNotifier extends io.intino.konos.alexandria.ui.displays.AlexandriaDisplayNotifier {

    public SumusOlapNotifier(io.intino.konos.alexandria.ui.displays.AlexandriaDisplay display, io.intino.konos.alexandria.rest.pushservice.MessageCarrier carrier) {
        super(display, carrier);
    }

	public void olapRange(Range value) {
		putToDisplay("olapRange", "value", value);
	}

	public void timeRange(Range value) {
		putToDisplay("timeRange", "value", value);
	}

	public void scaleList(java.util.List<Scale> value) {
		putToDisplay("scaleList", "value", value);
	}

	public void updateScale(Scale value) {
		putToDisplay("updateScale", "value", value);
	}

	public void enableDrill() {
		putToDisplay("enableDrill");
	}

	public void disableDrill() {
		putToDisplay("disableDrill");
	}

	public void enableFilter() {
		putToDisplay("enableFilter");
	}

	public void disableFilter() {
		putToDisplay("disableFilter");
	}

	public void filtering() {
		putToDisplay("filtering");
	}

	public void notFiltering() {
		putToDisplay("notFiltering");
	}

	public void drilling() {
		putToDisplay("drilling");
	}

	public void notDrilling() {
		putToDisplay("notDrilling");
	}

	public void refreshDrill(Drill value) {
		putToDisplay("refreshDrill", "value", value);
	}

	public void refreshFilterList(java.util.List<Filter> value) {
		putToDisplay("refreshFilterList", "value", value);
	}

	public void ticketList(java.util.List<Ticket> value) {
		putToDisplay("ticketList", "value", value);
	}

	public void selectTicketList(java.util.List<Ticket> value) {
		putToDisplay("selectTicketList", "value", value);
	}

	public void byCategorization(Reference value) {
		putToDisplay("byCategorization", "value", value);
	}

	public void chartList(java.util.List<Chart> value) {
		putToDisplay("chartList", "value", value);
	}

	public void selectChart(String value) {
		putToDisplay("selectChart", "value", value);
	}

	public void openAnalyzeDialog() {
		putToDisplay("openAnalyzeDialog");
	}

	public void closeAnalyzeDialog() {
		putToDisplay("closeAnalyzeDialog");
	}
}
